@@ -18,6 +18,8 @@
           real*8 EupperBndCS    ! Compton scattering is neglected Eg> this E
           integer IncGp         ! Include gp interactions or not
           logical Trace         ! how to take trace info.
+          real*8 TraceErg(6)    ! a,b,c,d,e,f; energy range of trace particles 
+                                ! (a, b), (c,d), (e,f) GeV are target region
           logical FreeC         ! first collision point is fixed or free
           real*8  EpsLeng       ! small distance to adjust boundary 
           real*8 RecoilKEmin    ! Knock-on electron's E> this E is treated
@@ -56,7 +58,8 @@
                                 ! If 0, neglected. if 1 considered. 
                                 ! It becomes effective, only if
                                 ! Xai=B/Bc*Eg/me/2 > 0.05.
-        common /epTrackC/  Bxu,  Byu,  Bzu, Exu, Eyu, Ezu,
+        common /epTrackC/ TraceErg,
+     *  Bxu,  Byu,  Bzu, Exu, Eyu, Ezu,
      *  DtMax, Tcoef, Tmin, KEmin,
      *  EminElec,  EminGamma, EupperBndCS, IncGp,
      *  Trace,  FreeC, EpsLeng, SyncLoop,
