@@ -19,8 +19,8 @@
      *     'the last 100  stacked tracks are listed on stdout',1)
 c
            write(*, *)
-     *         ' #  k charge    e            x           z         wz'
-           do i = Stack_pos, Stack_pos - 100, -1
+     *         ' #  k charge    Et            x           y         wz'
+           do i = Stack_pos-1, Stack_pos - 100, -1
               write(*, *) i, Stack(i).p.code, 
      *             Stack(i).p.charge, Stack(i).p.fm.p(4),
      *             Stack(i).pos.x,
@@ -120,13 +120,11 @@ c                vectors are in local.c
 c                make cosmos ptcl; e may not be informed. g may  not be,
 c                                  if IncGp=0.
           call ep2cosPtcl(aTrack.p)
-
           Stack_pos = Stack_pos - 1
           Cn = aTrack.cn   ! this may be used in epchckE
 c              do business when a new component appear
           call epnewComp
           call epchckE(aTrack, icon)
-
           if(icon .ne. 0) goto 10
 
        else
